base=/usr/ports/lang/cacao
wrksrc=w-cacao-0.95/cacao-0.95
test x"$1" = x -o x"$2" = x && echo usage && exit 0
(cd $base/$wrksrc; find src | grep "$2" | grep -v '\.orig$'  > /tmp/match)
if eval test "`wc -l </tmp/match`" -gt 1; then
	# if the named one exists then it wins
	if grep "$2\$" /tmp/match >/tmp/match1; then
		cp /tmp/match1 /tmp/match
	else
		echo "[ambiguous]" 1>&2
		cat /tmp/match
		exit
	fi
fi
if eval test "`wc -l </tmp/match`" -eq 0; then
	echo "[not found]" 1>&2
	exit
fi
file="`cat /tmp/match`"
case "$1" in
	find )
		echo "[unique]" 1>&2
		cat /tmp/match
		;;
	echo )
		echo $base/w-cacao-0.95/cacao-0.95/$file
		echo $base/files/tmp/cacao-0.95/$file
		;;

	ls )
		ls -l $base/w-cacao-0.95/cacao-0.95/$file
		ls -l $base/files/tmp/cacao-0.95/$file
		;;

	mkdir )
		mkdir -p $base/files/tmp/cacao-0.95/`dirname $file`
		;;

	cp )
		cp -p $base/w-cacao-0.95/cacao-0.95/$file $base/files/tmp/cacao-0.95/$file
		;;

	diff )
		diff -c $base/w-cacao-0.95/cacao-0.95/$file $base/files/tmp/cacao-0.95/$file
		;;

	gvim | vim | gvimdiff )
		eval $1 $base/w-cacao-0.95/cacao-0.95/$file $base/files/tmp/cacao-0.95/$file
		;;

	* )
		if test -x "$1"; then
			eval $1 $base/w-cacao-0.95/cacao-0.95/$file $base/files/tmp/cacao-0.95/$file
		else
			echo usage
		fi
		;;
esac
